@@ -33,9 +33,10 @@
 #  define SENDLATER_DEPRECATED_NO_EXPORT SENDLATER_NO_EXPORT SENDLATER_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define SENDLATER_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef SENDLATER_NO_DEPRECATED
+#    define SENDLATER_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
